@@ -30,11 +30,15 @@
  * Various utility functions.
  */
 
+#include "config.h"
 #include "latexila-utils.h"
 #include <string.h>
-#include "dh-dconf-migration.h"
 #include "latexila-synctex.h"
 
+#if HAVE_DCONF_MIGRATION
+#include "dh-dconf-migration.h"
+#endif
+
 static gint
 get_extension_position (const gchar *filename)
 {
@@ -467,6 +471,9 @@ latexila_utils_create_parent_directories (GFile   *file,
  * Returns: (transfer floating): a #GtkContainer containing @widget_top and
  * @widget_bottom.
  */
+/* TODO try to simply add the GTK_STYLE_CLASS_LINKED class to the
+ * GtkStyleContext of a GtkGrid.
+ */
 GtkWidget *
 latexila_utils_join_widgets (GtkWidget *widget_top,
 			     GtkWidget *widget_bottom)
@@ -493,6 +500,7 @@ latexila_utils_join_widgets (GtkWidget *widget_top,
 static void
 migrate_latexila_to_gnome_latex_gsettings (void)
 {
+#if HAVE_DCONF_MIGRATION
 	DhDconfMigration *migration;
 	gint i;
 
@@ -562,6 +570,9 @@ migrate_latexila_to_gnome_latex_gsettings (void)
 	}
 
 	_dh_dconf_migration_free (migration);
+#else
+	g_warning ("LaTeXila -> GNOME LaTeX dconf migration not supported.");
+#endif
 }
 
 static void
